[glib] gsubprocesslauncher: Use "env" instead of "environ"



commit c26c557908fe3083e9470b2a191cd53dc907138d
Author: Morten Welinder <terra gnome org>
Date:   Thu Dec 26 07:37:17 2013 -0500

    gsubprocesslauncher: Use "env" instead of "environ"
    
    The latter may come from system headers.
    
    https://bugzilla.gnome.org/show_bug.cgi?id=721059

 gio/gsubprocesslauncher.c |    6 +++---
 gio/gsubprocesslauncher.h |    2 +-
 2 files changed, 4 insertions(+), 4 deletions(-)
---
diff --git a/gio/gsubprocesslauncher.h b/gio/gsubprocesslauncher.h
index 3187690..611730e 100644
--- a/gio/gsubprocesslauncher.h
+++ b/gio/gsubprocesslauncher.h
@@ -56,7 +56,7 @@ GSubprocess *           g_subprocess_launcher_spawnv                    (GSubpro
 
 GLIB_AVAILABLE_IN_2_40
 void                    g_subprocess_launcher_set_environ               (GSubprocessLauncher   *self,
-                                                                         gchar                **environ);
+                                                                         gchar                **env);
 
 GLIB_AVAILABLE_IN_2_40
 void                    g_subprocess_launcher_setenv                    (GSubprocessLauncher   *self,


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/gio/gsubprocesslauncher.c b/gio/gsubprocesslauncher.c
index 3b15300..7b1ca48 100644
--- a/gio/gsubprocesslauncher.c
+++ b/gio/gsubprocesslauncher.c
@@ -224,7 +224,7 @@ g_subprocess_launcher_new (GSubprocessFlags flags)
 /**
  * g_subprocess_launcher_set_environ:
  * @self: a #GSubprocess
  * @environ: the replacement environment
  *
  * Replace the entire environment of processes launched from this
  * launcher with the given 'environ' variable.
@@ -244,10 +244,10 @@ g_subprocess_launcher_new (GSubprocessFlags flags)
  **/
 void
 g_subprocess_launcher_set_environ (GSubprocessLauncher  *self,
-                                   gchar               **environ)
+                                   gchar               **env)
 {
   g_strfreev (self->envp);
-  self->envp = g_strdupv (environ);
+  self->envp = g_strdupv (env);
 }
 
 /**
@@ -224,7 +224,7 @@ g_subprocess_launcher_new (GSubprocessFlags flags)
  * g_subprocess_launcher_set_environ:
  * @self: a #GSubprocess
- * @environ: the replacement environment
+ * @env: the replacement environment
  *
  * Replace the entire environment of processes launched from this